import { AxiosError, toFormData } from 'axios'
import { useMutation as useRQMutation, UseMutationOptions } from 'react-query'

import { Formalization } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace RunTestsStep1Mutation {
  export type Params = {
    id: Formalization['id']
    strategyFile: File
    testCasesInstantiationFile: File
  }
  export type Response = string

  export const key = ['formalization', 'run-tests-step-1']

  export const mutationFn = (params: Params) =>
    axiosService
      .post<Response>(
        `/formalization/${params.id}/run-tests-step-1`,
        toFormData(params)
      )
      .then((res) => res.data)

  export const useMutation = (
    options: UseMutationOptions<Response, AxiosError, Params> = {}
  ) => {
    return useRQMutation(mutationFn, { ...options, mutationKey: key })
  }
}
